==> mysocials_0.2-1.tar.gz: mysocials-0.2/src/ui/ui_general.h <==
/*
 * ui_general.h - UI of MSA program.
 * This file is part of MSA program.
 *
 * Copyright (C) 2009 - Andrey Bogachev
 *
 * MSA program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * MSA program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with MSA program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor,
 * Boston, MA  02110-1301  USA
 */

#ifndef _UI_GENERAL_
#define _UI_GENERAL_

#include <stdio.h>
#include <string.h>
#include <gtk/gtk.h>
#include <hildon/hildon-program.h>
#include <gdk/gdk.h>
#include <gdk/gdkx.h>
#include <gtk/gtkwidget.h>
#include "../msa.h"
#include "../msa_module.h"
#include "../kernel/general.h"
#include "ui_callback.h"
#include "ui_init.h"
#include <curl/curl.h>
#include <curl/easy.h>

/* CLASS */
#define PROFILE "profile"
#define SETTINGS "settings"
#define FRIENDS "friends"
#define MESSAGES "messages"
#define SYSTEM_MESSAGES "systemMessages"

/* FUNCTIONS */
#define GET_SETTINGS "getSettings"
#define GET_PROFILE "getProfile"
#define GET_FRIENDSLIST "getListFriends"
#define UPDATE_PROFILE "updateProfile"
#define SET_PROFILE "setProfile"
#define GET_INBOX "getInboxMessages"
#define GET_OUTBOX "getOutboxMessages"
#define ERROR_MESSAGE "errorMessage"
#define INFO_MESSAGE "infoMessage"
#define CAPTCHA_MSG "captchaMessage"

#define DIR DATADIR"/msa/ui/"
#define IMG_ADDF DIR"addcontact.png"
#define IMG_CLER DIR"clear.png"
#define IMG_CONT DIR"contact.png"
#define IMG_COMP DIR"compose.png"
#define IMG_EXIT DIR"exit.png"
#define IMG_FIND DIR"search.png"
#define IMG_FRND DIR"contacts.png"
#define IMG_FRST DIR"first.png"
#define IMG_FROM DIR"from.png"
#define IMG_FULL DIR"full.png"
#define IMG_HELP DIR"help.png"
#define IMG_LAST DIR"last.png"
#define IMG_MSSG DIR"messages.png"
#define IMG_MYSC DIR"mysocials.png"
#define IMG_NEXT DIR"next.png"
#define IMG_PRFL DIR"profile.png"
#define IMG_REFR DIR"refresh.png"
#define IMG_PREV DIR"prev.png"
#define IMG_SEPR DIR"separator.png"
#define IMG_SETS DIR"settings.png"
#define IMG_SORT DIR"sort.png"
#define IMG_SRVC DIR"service.png"
#define IMG_TOOL DIR"tool.png"

/* SRINGS: RU
#define STR_PROG "MySocials"
#define STR_STRT "Начало"
#define STR_EXIT "Выход"
#define STR_HELP "Справка"
#define STR_FULL "Полный экран"
#define STR_TOOL "Инструменты"
#define STR_GET  "Получить"
#define STR_SAVE "Сохранить"
#define STR_GO   "Вперёд!"
#define STR_NAME "Имя"
#define STR_LAST_NAME "Фамилия"
#define STR_COUNTRY "Страна"
#define STR_CITY "Город"
#define STR_GENDER "Пол"
#define STR_BIRTHDATE "Дата рождения"
#define STR_POLITICAL "Политические взгляды"
#define STR_MARITAL "Семейное положение"
#define STR_WLCM "Настроить сервисы:"
*/

/* STRINGS: EN */
#define STR_BACK "Back"
#define STR_BRTH "Birthdate"
#define STR_CITY "City"
#define STR_CNCL "Cancel"
#define STR_CMPS "Compose"
#define STR_CTRY "Country"
#define STR_EDIT "Edit"
#define STR_EMPT "---"
#define STR_EXIT "Exit"
#define STR_FIND "Find"
#define STR_FRDS "Friends"
#define STR_FULL "Full screen"
#define STR_GET_ "Get"
#define STR_GNDR "Gender"
#define STR_GO__ "Go!"
#define STR_HELP "Help"
#define STR_JOIN "Join with..."
#define STR_LSTN "Last Name"
#define STR_MRTL "Marital status"
#define STR_MSGS "Messages"
#define STR_NMSG "New message"
#define STR_NAME "First Name"
#define STR_OK__ "Ok"
#define STR_PLTC "Political views"
#define STR_PR2J "profiles to join"
#define STR_PRFL "Profile"
#define STR_PROG "MySocials"
#define STR_RPLY "Reply"
#define STR_RSLT "Search results for"
#define STR_SAVE "Save"
#define STR_SEND "Send"
#define STR_SETP "Setup services"
#define STR_SLCT "Select"
#define STR_SETS "Settings"
#define STR_STRT "Start"
#define STR_THEN "Then press Go!"
#define STR_TOOL "Toolbar"
#define STR_TO   " to "
#define STR_UPDT "Refresh"
#define STR_ZEROS "0 - 0 / 0"
#define STR_INCM " Incoming"
#define STR_SENT " Sent"
#define STR_ABOUT "MySocials is a client for social networks\n\
----------------------------------------\n\
Developers:\n\
        A. Bogachev\n\
        I. Burlak\n\
        A. Lomov\n\
        S. Zakharov\n\
----------------------------------------\n\
for more information visit:\n\
http://oss.fruct.org/wiki/Maemo-VKontakte\n"				

#define TYPE_IMAGE "img"
#define TYPE_NUMBR "number"
#define TYPE_STRNG "string"
#define TYPE_SELCT "select"
#define TYPE_STRCT "struct"
#define TYPE_DATE "date"
#define TYPE_BOOL "boolean"

#define MARKUP "<span foreground=\"#777777\" size=\"10000\">"
#define MARKUP1 "<span foreground=\"#777777\" size=\"25000\">"
#define MARKUP2 "<span foreground=\"#777777\" size=\"30000\">"
#define MARKUP_OFFLINE "<span foreground=\"#777777\" size=\"15000\">"
#define MARKUP_ONLINE "<span foreground=\"#555555\" background=\"#aaffaa\" size=\"15000\">"
#define MARKUP_READ "<span foreground=\"#777777\" size=\"15000\">"
#define MARKUP_UNREAD "<span foreground=\"#555555\" background=\"#aaffaa\" size=\"15000\">"
#define PUKRAM "</span>"

#define SIZE_HELP 200
#define TIMEOUT   150
#define PADDING   10
#define MIN_HEIGHT 40
#define MIN_WIDTH 200
#define MIN_WIDTH_PHOTO 80
#define MIN_WIDTH_CONTROL 80
#define MIN_MSG_WIDTH 500
#define MIN_TASKS_WIDTH 90
#define MAX_HEIGHT_PHOTO 250
#define FRIENDS_PER_PAGE 10
#define MESSAGES_PER_PAGE 10
#define TXT_HELP DIR"help.txt"


msa_module* kernel;

typedef enum _mbox 
{
    INBOX,
    SENT
}mbox;


/* UI data struct */
typedef struct _UIdata   UIdata;
struct _UIdata {
    /* Basic Items */
    HildonProgram* program;
    HildonWindow* window;
    HildonWindow* window_help;
    GtkWidget* notebook;
    GtkWidget* tasks;
    GtkWidget* boxes[5];
    GtkWidget* taskboxes[5];
    GtkWidget* box_profile;
    

    GtkWidget* box_service;
    GtkWidget* box_setting;
    GtkWidget* button_full;
    GtkWidget* list_drvs;
    
    GtkWidget* entry_logn;
    GtkWidget* entry_pass;
    GtkWidget* entry_auto;
    GtkWidget* entry_actv;
    
    GtkWidget* entry_labl;
    GtkWidget* entry_date;
    GtkWidget* entry_text;
    GtkWidget* entry_comb;
    
    gboolean empty_profile;
    
    // transit data
    xmlDocPtr ui_request;
    xmlDocPtr response;
    GHashTable* table_imgs;
    
    GSource* source_time;
    gboolean full;
    gboolean help;
    gboolean tool;  
    int page;
    int prev;
    int num_srvs;
    int srvc;

    /* Friends */
    gboolean ascending;
    gboolean empty_friends;
    gboolean friends_filter;
    
    int num_frds;
    int page_frds;
    
    GtkWidget* box_friend;
    GtkWidget* box_friends;
    GtkWidget* box_friends_list;
    GtkWidget* box_friends_navi;
    GtkWidget* box_friends_result;
    GtkWidget* box_friends_profile;
    GtkWidget* label_friends_page;
    GtkWidget* label_friends_filter;

	GtkWidget* button_friends_page_prev;
	GtkWidget* button_friends_page_next;
	GtkWidget* button_friends_page_frst;
	GtkWidget* button_friends_page_last;
    
    /* Messages */
    gboolean empty_messages;
    mbox msgs_box;
    int page_msgs;
    int num_msgs;
    GtkWidget* label_messages_page;
    GtkWidget* box_messages;
    GtkWidget* box_messages_list;
    GtkWidget* box_message_reply;

	GtkWidget* button_messages_page_prev;
	GtkWidget* button_messages_page_next;
	GtkWidget* button_messages_page_frst;
	GtkWidget* button_messages_page_last;
    
    //GtkWidget*    entry_host;           // textentry used to input host
    //GtkWidget*    entry_port;           // textentry that is used to input port
    //GtkWidget*    button_connect;       // button connect and disconnect 
    //GtkWidget*    STR_connect;        // label connect and disconnect 
    //GtkWidget*    table;
    
    /* Strings */
    gchar* str_page[5];
    gchar* str_task[4];
    
    /* Toolbar */
    GtkWidget*   toolbar;
    GtkToolItem* tool_sepr;
    GtkToolItem* tool_full;
    GtkToolItem* tool_exit;
    GtkToolItem* tool_help;
    GtkToolItem* tool_tool;
    
    /* Menu */
    GtkWidget* menu_tool;
    GtkWidget* menu_full;
    GtkWidget* menu_exit;
    GtkWidget* menu_help;
    GtkWidget* menu_sepr;
    
    /* Drivers */
    GList* drivers;    
};

UIdata* ui_data;

/* MESSAGE STRUCT */
typedef struct _Message   Message;
struct _Message {
    gchar* str_sender_id;
    gchar* str_sender_name;
    gchar* str_recipient_id;
    gchar* str_recipient_name;
    gchar* str_date;
    gchar* str_time;
    gchar* str_status;
    gchar* str_text;
};

/* FRIEND STRUCT */
typedef struct _Friend   Friend;
struct _Friend {
    gchar* str_name;
    gchar* str_id;
    gchar* str_status;
    gchar* str_img;
    gchar* str_uri;
};


/*  */
typedef struct _InputWidget InputWidget;
struct _InputWidget {
    GtkWidget* input;
};

/* KERNEL RESPONSE */
static void callback_kernel_response (xmlChar* request, xmlChar** response);
xmlXPathObject* xpath(char* req, xmlDocPtr doc);

/* HELP FUNC */
void ui_init_help();


#endif

==> mysocials_0.2-1.3.tar.gz: mysocials-0.2/src/ui/ui_general.h <==
/*
 * ui_general.h - UI of MSA program.
 * This file is part of MSA program.
 *
 * Copyright (C) 2009 - Andrey Bogachev
 *
 * MSA program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * MSA program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with MSA program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor,
 * Boston, MA  02110-1301  USA
 */

#ifndef _UI_GENERAL_
#define _UI_GENERAL_

#include <stdio.h>
#include <string.h>
#include <gtk/gtk.h>
#include <hildon/hildon-program.h>
#include <gdk/gdk.h>
#include <gdk/gdkx.h>
#include <gtk/gtkwidget.h>
#include "../msa.h"
#include "../msa_module.h"
#include "../kernel/general.h"
#include "ui_callback.h"
#include "ui_init.h"
#include <curl/curl.h>
#include <curl/easy.h>

/* CLASS */
#define PROFILE "profile"
#define SETTINGS "settings"
#define FRIENDS "friends"
#define MESSAGES "messages"
#define SYSTEM_MESSAGES "systemMessages"

/* FUNCTIONS */
#define GET_SETTINGS "getSettings"
#define GET_PROFILE "getProfile"
#define GET_FRIENDSLIST "getListFriends"
#define UPDATE_PROFILE "updateProfile"
#define SET_PROFILE "setProfile"
#define GET_INBOX "getInboxMessages"
#define GET_OUTBOX "getOutboxMessages"
#define ERROR_MESSAGE "errorMessage"
#define INFO_MESSAGE "infoMessage"
#define CAPTCHA_MSG "captchaMessage"

#define DIR DATADIR"/msa/ui/"
#define IMG_ADDF DIR"addcontact.png"
#define IMG_CLER DIR"clear.png"
#define IMG_CONT DIR"contact.png"
#define IMG_COMP DIR"compose.png"
#define IMG_EXIT DIR"exit.png"
#define IMG_FIND DIR"search.png"
#define IMG_FRND DIR"contacts.png"
#define IMG_FRST DIR"first.png"
#define IMG_FROM DIR"from.png"
#define IMG_FULL DIR"full.png"
#define IMG_HELP DIR"help.png"
#define IMG_LAST DIR"last.png"
#define IMG_MSSG DIR"messages.png"
#define IMG_MYSC DIR"mysocials.png"
#define IMG_NEXT DIR"next.png"
#define IMG_PRFL DIR"profile.png"
#define IMG_REFR DIR"refresh.png"
#define IMG_PREV DIR"prev.png"
#define IMG_SEPR DIR"separator.png"
#define IMG_SETS DIR"settings.png"
#define IMG_SORT DIR"sort.png"
#define IMG_SRVC DIR"service.png"
#define IMG_TOOL DIR"tool.png"

/* SRINGS: RU
#define STR_PROG "MySocials"
#define STR_STRT "Начало"
#define STR_EXIT "Выход"
#define STR_HELP "Справка"
#define STR_FULL "Полный экран"
#define STR_TOOL "Инструменты"
#define STR_GET  "Получить"
#define STR_SAVE "Сохранить"
#define STR_GO   "Вперёд!"
#define STR_NAME "Имя"
#define STR_LAST_NAME "Фамилия"
#define STR_COUNTRY "Страна"
#define STR_CITY "Город"
#define STR_GENDER "Пол"
#define STR_BIRTHDATE "Дата рождения"
#define STR_POLITICAL "Политические взгляды"
#define STR_MARITAL "Семейное положение"
#define STR_WLCM "Настроить сервисы:"
*/

/* STRINGS: EN */
#define STR_BACK "Back"
#define STR_BOUT "About"
#define STR_BRTH "Birthdate"
#define STR_CITY "City"
#define STR_CNCL "Cancel"
#define STR_CMPS "Compose"
#define STR_CTRY "Country"
#define STR_EDIT "Edit"
#define STR_EMPT "---"
#define STR_EXIT "Exit"
#define STR_FIND "Find"
#define STR_FRDS "Friends"
#define STR_FULL "Full screen"
#define STR_GET_ "Get"
#define STR_GNDR "Gender"
#define STR_GO__ "Go!"
#define STR_HELP "Help"
#define STR_JOIN "Join with..."
#define STR_LSTN "Last Name"
#define STR_MRTL "Marital status"
#define STR_MSGS "Messages"
#define STR_NMSG "New message"
#define STR_NAME "First Name"
#define STR_OK__ "Ok"
#define STR_PLTC "Political views"
#define STR_PR2J "profiles to join"
#define STR_PRFL "Profile"
#define STR_PROG "MySocials"
#define STR_RPLY "Reply"
#define STR_RSLT "Search results for"
#define STR_SAVE "Save"
#define STR_SEND "Send"
#define STR_SETP "Setup services"
#define STR_SLCT "Select"
#define STR_SETS "Settings"
#define STR_STRT "Start"
#define STR_THEN "Then press Go!"
#define STR_TOOL "Toolbar"
#define STR_TO   " to "
#define STR_UPDT "Refresh"
#define STR_ZEROS "0 - 0 / 0"
#define STR_INCM " Incoming"
#define STR_SENT " Sent"

#define STR_ABOUT "MySocials is a mobile client to access \
services of social networks. \
Distributed under GNU GPL license (see COPYING). \
Please visit:\n\
http://oss.fruct.org/wiki/Maemo-VKontakte\n\
for additional info, updates and documentation\n\
----------------------------------------\n\
Developers:\n\
    A. Bogachev <bogachev@cs.karelia.ru>\n\
    I. Burlak <burlak@cs.karelia.ru>\n\
    A. Lomov <lomov@cs.karelia.ru>\n\
    S. Zakharov <szaharov@cs.karelia.ru>\n\
    A. Borodin <aborod@cs.karelia.ru>\n\
    K. Kulakov <kulakov@cs.karelia.ru>"
#define STR_HELPT "Introduction\n\
This is MySocials, version 0.2. MySocials is the client for\
social networks with cross profile features. With MySocials\
you will be able to edit your profile entries, manage contacts\
(friend lists) and send messages. You will also be able to\
join contacts from different services if they represent the\
same person.\n\n\
Currently the interaction with VKontakte services only is enabled.\
A short time later there will be support of Jabber, Facebook and\
other social networks and instant messenger services."
/*\n\n\
Using MySocials\n\
After program start at first time you should fill and save account\
information for each supported service. In particular for VKontakte\
you should specify an email, password and mailbox autoupdate\
interval. You are supposed to have the accounts otherwise you\
should sign up by browser.\n\n\
Next you should press \"Go\" button to proceed to main window.\
Using left-side buttons you can switch between profile, contacts,\
messages and setup forms.\n\n\
User profile is fetched automatically when the form is activated.\
Contact list should be updated manually.\n\n\
Clicking on user picture in contact list will show you user profile\
form. Also clicking on envelope button allows to compose and send a\
message. Contacts can be sorted and also contact search feature is\
provided.\n\n\
On mailbox form you can look through the messages and reply.\n\n\
License information\n\
MySocials is free software, distributed under the terms of the\
[GNU] General Public License as published by the Free Software\
Foundation, version 2.1 of the License.  For more information,\
see the file COPYING.\n\n\
Privacy Statement\n\
We claim that your personal info will never be transferred to\
third parties.\n\n\
Reporting Bugs\n\
Bug reports for MySocials should be sent to:\
http://maemo.cs.karelia.ru/bugzilla/enter_bug.cgi?product=mysocials\n\
Enjoy!"
*/
#define TYPE_IMAGE "img"
#define TYPE_NUMBR "number"
#define TYPE_STRNG "string"
#define TYPE_SELCT "select"
#define TYPE_STRCT "struct"
#define TYPE_DATE "date"
#define TYPE_BOOL "boolean"

#define MARKUP "<span foreground=\"#aaaaaa\">"
#define MARKUP1 "<span foreground=\"#aaaaaa\">"
#define MARKUP2 "<span foreground=\"#aaaaaa\">"
#define MARKUP_OFFLINE "<span foreground=\"#aaaaaa\">"
#define MARKUP_ONLINE "<span foreground=\"#777777\" background=\"#aaffaa\">"
#define MARKUP_READ "<span foreground=\"#aaaaaa\">"
#define MARKUP_UNREAD "<span foreground=\"#777777\" background=\"#aaffaa\">"
#define PUKRAM "</span>"

#define SIZE_HELP 200
#define TIMEOUT   150
#define PADDING   10
#define MIN_HEIGHT 40
#define MIN_WIDTH 200
#define MIN_WIDTH_PHOTO 80
#define MIN_WIDTH_CONTROL 80
#define MIN_MSG_WIDTH 500
#define MIN_TASKS_WIDTH 90
#define MAX_HEIGHT_PHOTO 250
#define FRIENDS_PER_PAGE 10
#define MESSAGES_PER_PAGE 10
#define TXT_HELP DIR"help.txt"


msa_module* kernel;

typedef enum _mbox 
{
    INBOX,
    SENT
}mbox;


/* UI data struct */
typedef struct _UIdata   UIdata;
struct _UIdata {
    /* Basic Items */
    HildonProgram* program;
    GtkWidget* window;
    GtkWidget* window_help;
    GtkWidget* window_bout;
    GtkWidget* notebook;
    GtkWidget* tasks;
    GtkWidget* boxes[5];
    GtkWidget* taskboxes[5];
    GtkWidget* box_profile;
    

    GtkWidget* box_service;
    GtkWidget* box_setting;
    GtkWidget* button_full;
    GtkWidget* list_drvs;
    
    GtkWidget* entry_logn;
    GtkWidget* entry_pass;
    GtkWidget* entry_auto;
    GtkWidget* entry_actv;
    
    GtkWidget* entry_labl;
    GtkWidget* entry_date;
    GtkWidget* entry_text;
    GtkWidget* entry_comb;
    
    gboolean empty_profile;
    
    // transit data
    xmlDocPtr ui_request;
    xmlDocPtr response;
    GHashTable* table_imgs;
    
    GSource* source_time;
    gboolean full;
    gboolean help;
    gboolean tool;  
    int page;
    int prev;
    int num_srvs;
    int srvc;

    /* Friends */
    gboolean ascending;
    gboolean empty_friends;
    gboolean friends_filter;
    
    int num_frds;
    int page_frds;
    
    GtkWidget* box_friend;
    GtkWidget* box_friends;
    GtkWidget* box_friends_list;
    GtkWidget* box_friends_navi;
    GtkWidget* box_friends_result;
    GtkWidget* box_friends_profile;
    GtkWidget* label_friends_page;
    GtkWidget* label_friends_filter;

	GtkWidget* button_friends_page_prev;
	GtkWidget* button_friends_page_next;
	GtkWidget* button_friends_page_frst;
	GtkWidget* button_friends_page_last;
    
    /* Messages */
    gboolean empty_messages;
    mbox msgs_box;
    int page_msgs;
    int num_msgs;
    GtkWidget* label_messages_page;
    GtkWidget* box_messages;
    GtkWidget* box_messages_list;
    GtkWidget* box_message_reply;

	GtkWidget* button_messages_page_prev;
	GtkWidget* button_messages_page_next;
	GtkWidget* button_messages_page_frst;
	GtkWidget* button_messages_page_last;
    
    //GtkWidget*    entry_host;           // textentry used to input host
    //GtkWidget*    entry_port;           // textentry that is used to input port
    //GtkWidget*    button_connect;       // button connect and disconnect 
    //GtkWidget*    STR_connect;        // label connect and disconnect 
    //GtkWidget*    table;
    
    /* Strings */
    gchar* str_page[5];
    gchar* str_task[4];
    
    /* Toolbar */
    GtkWidget*   toolbar;
    GtkToolItem* tool_sepr;
    GtkToolItem* tool_full;
    GtkToolItem* tool_exit;
    GtkToolItem* tool_help;
    GtkToolItem* tool_tool;
    
    /* Menu */
    GtkWidget* menu_tool;
    GtkWidget* menu_full;
    GtkWidget* menu_exit;
    GtkWidget* menu_help;
    GtkWidget* menu_sepr;
    
    /* Drivers */
    GList* drivers;    
};

UIdata* ui_data;

/* MESSAGE STRUCT */
typedef struct _Message   Message;
struct _Message {
    gchar* str_sender_id;
    gchar* str_sender_name;
    gchar* str_recipient_id;
    gchar* str_recipient_name;
    gchar* str_date;
    gchar* str_time;
    gchar* str_status;
    gchar* str_text;
};

/* FRIEND STRUCT */
typedef struct _Friend   Friend;
struct _Friend {
    gchar* str_name;
    gchar* str_id;
    gchar* str_status;
    gchar* str_img;
    gchar* str_uri;
};


/*  */
typedef struct _InputWidget InputWidget;
struct _InputWidget {
    GtkWidget* input;
};

/* KERNEL RESPONSE */
static void callback_kernel_response (xmlChar* request, xmlChar** response);
xmlXPathObject* xpath(char* req, xmlDocPtr doc);

/* HELP FUNC */
void ui_init_help();


#endif
